summaryrefslogtreecommitdiffstats
path: root/buildtools/qmake/scope.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-14 16:45:05 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-14 16:45:05 +0000
commit48d4a26399959121f33d2bc3bfe51c7827b654fc (patch)
tree5ae5e6e00d3ba330b7b8be9bc097154b6bc739e8 /buildtools/qmake/scope.h
parent7e701ace6592d09e1f2c0cf28c7d6d872d78f4f5 (diff)
downloadtdevelop-48d4a26399959121f33d2bc3bfe51c7827b654fc.tar.gz
tdevelop-48d4a26399959121f33d2bc3bfe51c7827b654fc.zip
TQt4 port kdevelop
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdevelop@1236710 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'buildtools/qmake/scope.h')
-rw-r--r--buildtools/qmake/scope.h66
1 files changed, 33 insertions, 33 deletions
diff --git a/buildtools/qmake/scope.h b/buildtools/qmake/scope.h
index 5cc609ce..a01adaad 100644
--- a/buildtools/qmake/scope.h
+++ b/buildtools/qmake/scope.h
@@ -64,7 +64,7 @@ public:
TQStringList variableValuesForOp( const TQString& variable, const TQString& op ) const;
// Fetch the variable values by running over the statements and adding/removing/setting
// as the encountered op's say, begin with the parent projects variableValues list
TQStringList variableValues( const TQString& variable, bool checkIncParent = true, bool fetchFromParent = true, bool evaluateSubScopes = false );
// Remove a variable+Op combination from the scope, if existant
@@ -86,8 +86,8 @@ public:
// Returns the absolute path of the dir containing the .pro file
TQString projectDir() const;
- // get the parent Scope
- Scope* parent() const { return m_parent; }
+ // get the tqparent Scope
+ Scope* tqparent() const { return m_parent; }
// Fetching sub-scopes
const TQValueList<Scope*> scopesInOrder() const { return m_scopes.values(); }
@@ -105,7 +105,7 @@ public:
* creates a new function scope at the end of this (Sub-)AST
* and a new include scope inside the new function scope.
* It returns the Scope wrapping the include-AST, the function scope AST
* can be accessed easily using the parent() method.
*/
Scope* createIncludeScope( const TQString& includeFile, bool negate = false );
@@ -125,8 +125,8 @@ public:
/* deletes the subproject (including the subdir if deleteSubdir is true) */
bool deleteSubProject( unsigned int, bool deleteSubdir );
- /* find out wether the project is Qt4 or Qt3 */
- bool isQt4Project() const ;
+ /* find out wether the project is TQt4 or TQt3 */
+ bool isTQt4Project() const ;
/* Provide a Map of Custom variables */
const TQMap<unsigned int, TQMap<TQString, TQString> > customVariables() const;
@@ -195,29 +195,29 @@ private:
/*
* Finds an existing variable, returns the end() of the statemenst if it is not found
*/
- TQValueList<QMake::AST*>::iterator findExistingVariable( const TQString& variable );
+ TQValueList<TQMake::AST*>::iterator findExistingVariable( const TQString& variable );
// Private constructors for easier subscope creation
/*
* just initializes the lists from the scope
*/
- Scope( const TQMap<TQString, TQString>& env, unsigned int num, Scope* parent, QMake::ProjectAST* root, QMakeDefaultOpts*, TrollProjectPart* part );
+ Scope( const TQMap<TQString, TQString>& env, unsigned int num, Scope* tqparent, TQMake::ProjectAST* root, TQMakeDefaultOpts*, TrollProjectPart* part );
/*
* reads the given filename and parses it. If it doesn't exist creates an empty
* ProjectAST with the given filename
*/
- Scope( const TQMap<TQString, TQString>& env, unsigned int num, Scope* parent, const TQString& filename, TrollProjectPart* part, bool isEnabled = true );
+ Scope( const TQMap<TQString, TQString>& env, unsigned int num, Scope* tqparent, const TQString& filename, TrollProjectPart* part, bool isEnabled = true );
/*
* Creates a scope for an include statement, parses the file and initializes the Scope
* Create an empty ProjectAST if the file cannot be found or parsed.
*/
- Scope( const TQMap<TQString, TQString>& env, unsigned int num, Scope* parent, QMake::IncludeAST* incast, const TQString& path, const TQString& incfile, QMakeDefaultOpts*, TrollProjectPart* part );
+ Scope( const TQMap<TQString, TQString>& env, unsigned int num, Scope* tqparent, TQMake::IncludeAST* incast, const TQString& path, const TQString& incfile, TQMakeDefaultOpts*, TrollProjectPart* part );
// runs through the statements until stopHere is found (or the end is reached, if stopHere is 0),
// using the given list as startvalue
// Changes the list using the +=, -=, = operations accordingly
- void calcValuesFromStatements( const TQString& variable, TQStringList& result, bool, QMake::AST* stopHere = 0, bool fetchFromParent = true, bool setDefault = true, bool evaluateSubScopes = false ) const;
+ void calcValuesFromStatements( const TQString& variable, TQStringList& result, bool, TQMake::AST* stopHere = 0, bool fetchFromParent = true, bool setDefault = true, bool evaluateSubScopes = false ) const;
// Check wether the two operators are compatible
static bool isCompatible( const TQString& op1, const TQString& op2);
@@ -228,15 +228,15 @@ private:
// Load and Save project files, these only work on ProjectScope's
bool loadFromFile( const TQString& filename );
- TQString funcScopeKey( QMake::ProjectAST* funcast ) const { return funcast->scopedID + "(" + funcast->args + ")"; }
+ TQString funcScopeKey( TQMake::ProjectAST* funcast ) const { return funcast->scopedID + "(" + funcast->args + ")"; }
unsigned int getNextScopeNum() { if( m_scopes.isEmpty() ) return 0; else return (m_scopes.keys().last()+1); }
TQStringList lookupVariable( const TQString& var );
- TQStringList resolveVariables( const TQStringList&, QMake::AST* = 0 ) const;
- TQStringList variableValues( const TQString& variable, QMake::AST*, bool fetchFromParent = true ) const;
- TQString resolveVariables( const TQString& , QMake::AST* ) const;
+ TQStringList resolveVariables( const TQStringList&, TQMake::AST* = 0 ) const;
+ TQStringList variableValues( const TQString& variable, TQMake::AST*, bool fetchFromParent = true ) const;
+ TQString resolveVariables( const TQString& , TQMake::AST* ) const;
// This function determines the currently used String for fileending, it can be \n, \r or \r\n
TQString getLineEndingString() const;
@@ -246,9 +246,9 @@ private:
void loadDefaultOpts();
- QMake::ProjectAST* m_root;
- QMake::IncludeAST* m_incast;
- TQMap<unsigned int, QMake::AssignmentAST*> m_customVariables;
+ TQMake::ProjectAST* m_root;
+ TQMake::IncludeAST* m_incast;
+ TQMap<unsigned int, TQMake::AssignmentAST*> m_customVariables;
TQMap<unsigned int, Scope*> m_scopes;
Scope* m_parent;
unsigned int m_maxCustomVarNum;
@@ -256,40 +256,40 @@ private:
TQString replaceWs(TQString);
// The "position" inside the parent scope that this scope starts at
unsigned int m_num;
bool m_isEnabled;
TrollProjectPart* m_part;
- QMakeDefaultOpts* m_defaultopts;
+ TQMakeDefaultOpts* m_defaultopts;
TQMap<TQString, TQStringList> m_varCache;
TQMap<TQString,TQString> m_environment;
#ifdef DEBUG
- class PrintAST : QMake::ASTVisitor
+ class PrintAST : TQMake::ASTVisitor
{
public:
PrintAST();
- virtual void processProject( QMake::ProjectAST* p );
- virtual void enterRealProject( QMake::ProjectAST* p );
+ virtual void processProject( TQMake::ProjectAST* p );
+ virtual void enterRealProject( TQMake::ProjectAST* p );
- virtual void leaveRealProject( QMake::ProjectAST* p );
+ virtual void leaveRealProject( TQMake::ProjectAST* p );
- virtual void enterScope( QMake::ProjectAST* p );
+ virtual void enterScope( TQMake::ProjectAST* p );
- virtual void leaveScope( QMake::ProjectAST* p );
+ virtual void leaveScope( TQMake::ProjectAST* p );
- virtual void enterFunctionScope( QMake::ProjectAST* p );
+ virtual void enterFunctionScope( TQMake::ProjectAST* p );
- virtual void leaveFunctionScope( QMake::ProjectAST* p );
+ virtual void leaveFunctionScope( TQMake::ProjectAST* p );
- virtual void processAssignment( QMake::AssignmentAST* a);
+ virtual void processAssignment( TQMake::AssignmentAST* a);
- virtual void processNewLine( QMake::NewLineAST* n);
+ virtual void processNewLine( TQMake::NewLineAST* n);
- virtual void processComment( QMake::CommentAST* a);
+ virtual void processComment( TQMake::CommentAST* a);
- virtual void processInclude( QMake::IncludeAST* a);
+ virtual void processInclude( TQMake::IncludeAST* a);
TQString replaceWs(TQString);
@@ -304,5 +304,5 @@ private:
#endif
-// kate: space-indent on; indent-width 4; tab-width 4; replace-tabs on
+// kate: space-indent on; indent-width 4; tab-width 4; tqreplace-tabs on
@@ -64,7 +64,7 @@ public:
TQStringList variableValuesForOp( const TQString& variable, const TQString& op ) const;
// Fetch the variable values by running over the statements and adding/removing/setting
- // as the encountered op's say, begin with the parent projects variableValues list
+ // as the encountered op's say, begin with the tqparent projects variableValues list
TQStringList variableValues( const TQString& variable, bool checkIncParent = true, bool fetchFromParent = true, bool evaluateSubScopes = false );
// Remove a variable+Op combination from the scope, if existant
@@ -105,7 +105,7 @@ public:
* and a new include scope inside the new function scope.
* It returns the Scope wrapping the include-AST, the function scope AST
- * can be accessed easily using the parent() method.
+ * can be accessed easily using the tqparent() method.
*/
Scope* createIncludeScope( const TQString& includeFile, bool negate = false );
@@ -256,40 +256,40 @@ private:
TQString replaceWs(TQString);
- // The "position" inside the parent scope that this scope starts at
+ // The "position" inside the tqparent scope that this scope starts at
unsigned int m_num;
bool m_isEnabled;